
/*******************************************************************************
Reading raw data and create SAS data sets; raw data maybe available upon request
*********************************************************************************/
libname ssex "libref ";
%let name=ssm_anim&sysdate;
filename odsout '.';
**import excel file: raw file maybe available at the conference upon request;

PROC IMPORT OUT=ssex.ssex DATAFILE="location of your input excel file"
  DBMS=  EXCELCS   REPLACE;	 
RUN;

proc sort data=ssex.ssex out=ssex;
  by statecode stateno;
run;
proc transpose data=ssex out=ssex2;
  by statecode stateno;
  var _004 _005 _006 _007 _008 _009 _010 _011 _012 _013 _014;
run;

data ssex3 (drop = stateno _label_ _name_ rename=(col1=legal_status)); 
  set ssex2;
  year=.; 
  year=_label_;
run;

proc sort data=ssex3 out=ssex4;
  by year statecode;
run;
/***************************************************************************
 Annotate dataset for state labels 
 These x and y locations are hard-coded, and only work with maps.us 
****************************************************************************/
data maplabel; 
  set maps.uscenter(where=(fipstate(state) not in ('PR' 'DC')));
  statecode=fipstate(state);
* move Hawaii's label slightly *;
  if statecode='HI' then 
    do; 
      x=x-.01; 
      y=y-.01;
    end;
  length function $8;
  retain flag 0;
  xsys='2'; 
  ysys='2'; 
  hsys='3';
  when='a'; 
  function='label'; 
  color='gray55'; 
  style="albany amt/bold"; 
  position='5';
  size=2.8; 
  text=trim(left(statecode)); 
  if ocean='Y' then
    do;                          
      position='6'; 
      output;    
      function='move';                                                      
      flag=1;
    end;
  else if flag=1 then 
    do;                                                                   
      function='draw'; 
      size=.25;
      flag=0;
    end;
  output;
run;


proc format;
  value $legfmt
  "CC Ban"    = "6th Circuit Court upholds bans in certain states"
  "FC Legal"  = "Federal Court rulings make same-sex marriage legal"
  "Legal"     = "Legalized at the State level"
  "NLNB"      = "Neither Legal nor Banned"
  "SC Ban"    = "State Constitutional Ban"
  "SL CU"     = "State Law allows Civil Unions"
  "SS Ban"    = "State Statute Ban" 
  "Supreme Ct"= "Supreme Court declines to review cases on State Bans"
;
run;
/**********************************************************************
Animation code starts here
***********************************************************************/
options dev=sasprtc printerpath=gif animduration=2 animloop=0
animoverlay=no animate=start center;

ODS LISTING CLOSE;
ODS HTML path=odsout body="&name..htm" 
   (title="Same Sex Marriage in the US") 
    style=sasweb;
goptions gunit=pct htitle=5 htext=3.0 ftitle="albany amt/bold" ftext="albany amt" ctext=gray33;

options nobyline;
/************************************************************************
 Select various colors to show animation for legal<green/blue>/banned<red>/neither legal nor band categories<yellow>
Make sure format is in alphabetic order  
*************************************************************************/
pattern1 v=s c=green;
pattern2 v=s c=blue;
pattern3 v=s c=green;
pattern4 v=s c=yellow;
pattern5 v=s c=red;
pattern6 v=s c=green;
pattern7 v=s c=red;
pattern8 v=s c=cxCDB5CD;

/***********************************************
add a little space to left and right of map 
************************************************/

title2 a=90 h=2 ' ';
title3 a=-90 h=2 ' ';

legend1 label=none  position=(bottom) shape=bar(.15in,.15in) value=(j=l);  
title1 ls=1.5 "Legal Status of Same Sex Marriage 2004 to 2014 ";

proc gmap data=ssex4  anno=maplabel
  map=maps.us (where=(statecode not in ('PR'))) all; 
  by year;
  id statecode; 
  note move=(55,85) height=11 font='albany amt/bold' "#byval(year)";
  choro legal_status / uniform  
  cdefault=white coutline=graydd
  legend=legend1
  des='' name="&name"; 
  format legal_status $legfmt.;
run;

quit;
ODS HTML CLOSE;
ODS LISTING;
